degrees

# XMLRésuméLibrary: User Guide

degree | Element Reference | description

## Name

degrees — Container for one or more degrees

## Synopsis

### Content Model

    (degree+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `degrees` element is a container for at least one `degree`.

### Parents

`degrees` may be contained in these elements: `academics`

## Examples

    <degrees>
      <degree>
        <level>BA</level>
        <major>Interstellar Basket Weaving</major>
      </degree>
      <degree>
        <level>Ph.D</level>
        <major>Aquatic Tennis Teaching</major>
      </degree>
    </degree>

degree | Element Reference | description